from django import template
from django.utils.encoding import force_unicode

import ttag
from ttag.core import BaseTag, DeclarativeArgsMetaclass
from ttag.tests.setup import models

register = template.Library()


class SelfRegisteringMetaclass(DeclarativeArgsMetaclass):

    def __new__(cls, name, bases, attrs):
        cls = DeclarativeArgsMetaclass.__new__(cls, name, bases, attrs)
        parents = [b for b in bases if isinstance(b, DeclarativeArgsMetaclass)]
        if parents:
            register.tag(cls._meta.name, cls)
        return cls


class TestTag(BaseTag):
    __metaclass__ = SelfRegisteringMetaclass


class NamedArg(TestTag):
    limit = ttag.IntegerArg(default=5, named=True)

    def output(self, data):
        if 'limit' in data:
            return 'The limit is %d' % data['limit']
        return 'No limit was specified'


class NamedKeywordArg(NamedArg):
    limit = ttag.IntegerArg(keyword=True)


class NoArgument(TestTag):

    def output(self, data):
        return 'No arguments here'


class Positional(TestTag):
    limit = ttag.IntegerArg()

    def output(self, data):
        return '%s' % data['limit']


class PositionalMixed(TestTag):
    limit = ttag.IntegerArg(default=5)
    as_ = ttag.BasicArg(named=True)

    def render(self, context):
        data = self.resolve(context)
        context[data['as']] = data['limit']
        return ''


class PositionalMixedkw(TestTag):
    value = ttag.Arg(required=False, null=True)
    default = ttag.Arg(keyword=True)

    def output(self, data):
        return unicode(data.get('value') or data['default'])


class PositionalOptional(TestTag):
    start = ttag.IntegerArg()
    finish = ttag.IntegerArg(required=False)

    def output(self, data):
        if 'finish' in data:
            start, finish = data['start'], data['finish']
        else:
            start, finish = 0, data['start']
        return ','.join([str(i) for i in range(start, finish)])


class PositionalOptionalMixed(TestTag):
    start = ttag.IntegerArg()
    finish = ttag.IntegerArg(required=False)
    step = ttag.IntegerArg(named=True)

    def output(self, data):
        if 'finish' in data:
            start, finish = data['start'], data['finish']
        else:
            start, finish = 0, data['start']
        return ','.join([str(i) for i in range(start, finish, data['step'])])


class ArgumentType(TestTag):
    age = ttag.IntegerArg(required=False, named=True)
    name_ = ttag.StringArg(required=False, named=True)
    url = ttag.ModelInstanceArg(model=models.Link, required=False, named=True)
    date = ttag.DateArg(required=False, named=True)
    time = ttag.TimeArg(required=False, named=True)
    datetime = ttag.DateTimeArg(required=False, named=True)
    flag = ttag.BooleanArg()

    def output(self, data):
        order = 'name age url date time datetime'.split()
        values = [unicode(data[x]) for x in order if x in data]
        if 'flag' in data:
            values.append('flag_is_set')
        return u' '.join(values)


class Constant(TestTag):
    start = ttag.Arg()
    to = ttag.ConstantArg()
    finish = ttag.Arg()

    def output(self, data):
        return '%s - %s' % (data['start'], data['finish'])


class KeywordsEcho(TestTag):
    keywords = ttag.KeywordsArg()

    def output(self, data):
        keywords = data['keywords'].items()
        return ', '.join('%s: %s' % (key, value) for key, value in keywords)


class DotCombine(TestTag):
    args = ttag.MultiArg()

    def output(self, data):
        args = [force_unicode(arg) for arg in data['args']]
        return '.'.join(args)


class DotCombineDefault(DotCombine):
    default = ttag.Arg(named=True)

    def output(self, data):
        args = [arg and force_unicode(arg) or data['default']
                for arg in data['args']]
        return '.'.join(args)


class Repeat(TestTag):
    count = ttag.IntegerArg()

    class Meta:
        block = True
        end_block = 'done'

    def render(self, context):
        data = self.resolve(context)
        output = []
        for i in range(data['count']):
            context.push()
            output.append(self.nodelist.render(context))
            context.pop()
        return ''.join(output)


class RepeatWithEmpty(TestTag):
    count = ttag.IntegerArg()

    class Meta:
        block = {'empty': False}
        end_block = 'stop'

    def render(self, context):
        data = self.resolve(context)
        if not data['count']:
            return self.nodelist_empty.render(context)
        output = []
        for i in range(data['count']):
            context.push()
            output.append(self.nodelist.render(context))
            context.pop()
        return ''.join(output)


class BaseInclude(TestTag):
    """
    A tag for testing KeywordsArg.
    """

    def output(self, data):
        out = 'including %s' % data['template']
        if data.get('with'):
            with_bits = data['with'].items()
            with_bits.sort(key=lambda bit: bit[0])
            out += ' with %s' % ' and '.join(['%s = %s' % (k, v)
                                              for k, v in with_bits])
        return out


class IncludeCompact(BaseInclude):
    template = ttag.Arg()
    with_ = ttag.KeywordsArg(named=True, required=False)


class IncludeVerbose(BaseInclude):
    template = ttag.Arg()
    with_ = ttag.KeywordsArg(named=True, required=False, compact=False,
                             verbose=True)


class IncludeMixed(BaseInclude):
    template = ttag.Arg()
    with_ = ttag.KeywordsArg(named=True, required=False, verbose=True)



from ttag.tests.main import TagExecutionTests, TestArgumentTypes, \
    PositionalTest, KeywordsArgTest
from ttag.tests.registration import RegisterTest
from ttag.tests.helpers import AsTag, TemplateTag



try:
    from ttag.args import Arg, BasicArg, BooleanArg, ConstantArg, DateArg, \
        DateTimeArg, IntegerArg, IsInstanceArg, KeywordsArg, \
        ModelInstanceArg, StringArg, TimeArg, MultiArg
    from ttag.core import Tag
    from ttag.exceptions import TagArgumentMissing, TagValidationError
    from ttag import helpers
except ImportError:
    # This allows setup.py to skip import errors which may occur if ttag is
    # being installed at the same time as Django.
    pass

VERSION = (2, 4)


def get_version(number_only=False):
    version = [str(VERSION[0])]
    number = True
    for bit in VERSION[1:]:
        if not isinstance(bit, int):
            if number_only:
                break
            number = False
        version.append(number and '.' or '-')
        version.append(str(bit))
    return ''.join(version)



from django import template

import ttag

register = template.Library()


class FishAs(ttag.helpers.AsTag):

    def output(self, data):
        return 'fish'


class AnotherFishAs(FishAs):
    pass


class MaybeAs(ttag.helpers.AsTag):

    class Meta:
        as_required = False

    def as_value(self, data, context):
        return 'maybe'


class DefaultAs(ttag.helpers.AsTag):

    class Meta:
        as_default = 'snake'

    def output(self, data):
        return 'hisss'


class OutputAs(ttag.helpers.AsTag):
    value = ttag.Arg()

    class Meta:
        as_required = False

    def as_value(self, data, context):
        return data['value']

    def as_output(self, data, context):
        return 'yes_as'


register.tag(FishAs)
register.tag(AnotherFishAs)
register.tag(MaybeAs)
register.tag(DefaultAs)
register.tag(OutputAs)



from os import path
import datetime

from django import template
from django.conf import settings
from django.test import TestCase

import ttag
from ttag.tests.setup import as_tags, template_tags

template.add_to_builtins(as_tags.__name__)
template.add_to_builtins(template_tags.__name__)


def render(contents, extra_context=None):
    return template.Template(contents).render(template.Context(extra_context))


class AsTag(TestCase):

    def test_simple(self):
        """
        A tag with named arguments works with or without the argument as long
        as a default value is set.
        """
        self.assertEqual(render('{% fish_as as out %}-{{ out }}'), '-fish')
        self.assertEqual(render('{% another_fish_as as out %}-{{ out }}'), '-fish')

    def test_optional(self):
        """
        A tag with named arguments works with or without the argument as long
        as a default value is set.
        """
        self.assertEqual(render('{% maybe_as %}-{{ out }}'), 'maybe-')
        self.assertEqual(render('{% maybe_as as out %}-{{ out }}'), '-maybe')

    def test_as_output(self):
        """
        A tag with named arguments works with or without the argument as long
        as a default value is set.
        """
        self.assertEqual(render('{% output_as 1 %}-{{ out }}'), '1-')
        self.assertEqual(render('{% output_as 1 as out %}-{{ out }}'),
                         'yes_as-1')

    def test_as_default(self):
        """
        A default variable name can be used (which will force ``as_required``
        to ``False``).
        """
        self.assertEqual(render('{% default_as %}...{{ snake }}'), '...hisss')

    def test_invalid_as_name(self):
        """
        A tag can't be create with an as_name which matches a named argument.
        """

        def make_bad_tag():
            class BadTag(ttag.helpers.AsTag):
                as_ = ttag.Arg(named=True)

        self.assertRaises(template.TemplateSyntaxError, make_bad_tag)


class TemplateTag(TestCase):

    def setUp(self):
        self.old_template_dirs = settings.TEMPLATE_DIRS
        settings.TEMPLATE_DIRS = [path.join(path.dirname(__file__), 'templates')]

    def tearDown(self):
        settings.TEMPLATE_DIRS = self.old_template_dirs

    def test_simple(self):
        """
        A tag with named arguments works with or without the argument as long
        as a default value is set.
        """
        self.assertRaises(template.TemplateSyntaxError, render, '{% go %}')
        self.assertEqual(render('{% go using "the_flow.html" %}'), 'yeah')

    def test_optional(self):
        today = datetime.datetime.today()
        self.assertEqual(render('{% ask "What date is it?" %}'), today.strftime('%h %d, %Y'))
        self.assertEqual(render('{% ask "What date is it" using "long.html" %}'), today.strftime('%B %d, %Y'))
        self.assertEqual(render('{% ask "What the frak?" %}'), "")

    def test_with_argument(self):
        self.assertEqual(render('{% do %}'), 'done')
        self.assertEqual(render('{% do it "now.html" %}'), 'already done')



from django import template
from django.test import TestCase

import ttag


class RegisterTest(TestCase):

    def test_names(self):
        register = template.Library()

        class Registration(ttag.Tag):
            pass

        class CamelCaseRegistration(ttag.Tag):
            pass

        class AlternateNameRegistration(ttag.Tag):

            class Meta:
                name = 'alt_name_registration'

        register.tag(Registration)
        register.tag(CamelCaseRegistration)
        register.tag(AlternateNameRegistration)

        self.assertEqual(len(register.tags), 3)
        self.assertTrue('registration' in register.tags)
        self.assertTrue('camel_case_registration' in register.tags)
        self.assertTrue('alt_name_registration' in register.tags)



import datetime

from django.test import TestCase
from django import template

import ttag
from ttag.tests.setup import tags, models

template.add_to_builtins(tags.__name__)


def render(contents, extra_context=None):
    return template.Template(contents).render(template.Context(extra_context))


class TagExecutionTests(TestCase):

    def test_default(self):
        """
        A tag with named arguments works with or without the argument as long
        as a default value is set.
        """
        self.assertEqual(render('{% named_arg %}'),
                         'The limit is %d' %
                         tags.NamedArg._meta.args['limit'].default)

        # Reset the limit tag to have no default (and be required, which is set
        # to False if a default was given.
        tags.NamedArg._meta.args['limit'].default = None
        tags.NamedArg._meta.args['limit'].required = True

        self.assertRaises(template.TemplateSyntaxError, render,
            '{% named_arg %}')

    def test_named(self):
        """
        Standard named argument syntax is ``{% tag arg value %}``
        """
        self.assertEqual(render('{% named_arg limit 200 %}'),
                         'The limit is 200')
        self.assertRaises(template.TemplateSyntaxError, template.Template,
                          '{% named_arg limit=25 %}')

    def test_named_keyword(self):
        self.assertEqual(render('{% named_keyword_arg limit=100 %}'),
                         'The limit is 100')
        self.assertRaises(template.TemplateSyntaxError, template.Template,
                          "{% named_keyword_arg limit 15 %}")

    def test_handle_args(self):
        """tags with no arguments take no arguments"""
        self.assertRaises(template.TemplateSyntaxError, template.Template,
                          '{% no_argument this fails %}')

    def test_constant_tag(self):
        """tags with no arguments take no arguments"""
        self.assertEqual(render('{% constant 1 to 2 %}'), '1 - 2')
        self.assertRaises(template.TemplateSyntaxError, template.Template,
                          '{% constant 1 t 2 %}', {'t': 'to'})

    def test_block_tag(self):
        """tags with a block meta option"""
        self.assertEqual(render('{% repeat 5 %}a{% done %}'), 'aaaaa')

    def test_multiple_block_tag(self):
        """tags with a block meta option"""
        self.assertEqual(render('{% repeat_with_empty 5 %}a{% empty %}b{% stop %}'), 'aaaaa')
        self.assertEqual(render('{% repeat_with_empty 0 %}a{% empty %}b{% stop %}'), 'b')


def build_invalid_positional_optional():

    class Tag(ttag.Tag):
        start = ttag.Arg(required=False)
        end = ttag.Arg()


class PositionalTest(TestCase):

    def test_positional(self):
        """
        Test that positional arguments work.
        """
        self.assertEqual(render('{% positional 10 %}'), u"10")

        self.assertRaises(template.TemplateSyntaxError, render,
                          '{% positional %}')
        self.assertRaises(template.TemplateSyntaxError, render,
                          '{% positional limit 10 %}')

    def test_positional_mixed(self):
        """
        Test that positional arguments work, mixed with named arguments.
        """
        self.assertEqual(render('{% positional_mixed 1 as a%}x{{ a }}'), 'x1')
        self.assertEqual(render('{% positional_mixed var as a%}x{{ a }}',
                                {'var': '2'}), 'x2')

    def test_positional_mixedkw(self):
        """
        Test that positional arguments work, mixed with keyword arguments.
        """
        self.assertEqual(render('{% positional_mixedkw 1 default=9 %}'), '1')
        self.assertEqual(render('{% positional_mixedkw var default=9 %}',
                                {'var': None}), '9')
        self.assertEqual(render('{% positional_mixedkw default=9 %}'), '9')

    def test_positional_optional(self):
        """
        Test that optional positional arguments work.
        """
        self.assertEqual(render('{% positional_optional 2 %}'), '0,1')
        self.assertEqual(render('{% positional_optional_mixed 10 step 2 %}'),
                         '0,2,4,6,8')

    def test_optional_last(self):
        """
        Test that an error is raised if optional positional arguments are
        followed by required ones.
        """
        self.assertRaises(template.TemplateSyntaxError,
                          build_invalid_positional_optional)


class TestArgumentTypes(TestCase):

    def test_model_instance_arg(self):
        content = '{% argument_type url object %}'
        object = models.Link(url='http://bing.com')
        self.assertEqual(render(content, {'object': object}),
                         unicode(object))

        self.assertRaises(ttag.TagValidationError, render, content,
                          {'object': int()})

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render, content)

    def test_integer_arg(self):
        self.assertEqual(render('{% argument_type age 101 %}'), '101')
        self.assertEqual(render('{% argument_type age a %}', {'a': 99}), '99')

        # IntegerArg.clean calls int(value), so string integers should be
        # converted.
        self.assertEqual(render('{% argument_type age "23" %}'), '23')
        self.assertEqual(render('{% argument_type age a %}', {'a': '7'}), '7')

        # Fail if value or variable can't be resolved as an integer.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type age "7b" %}')
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type age age %}', {'age': 'NaN'})

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type age age %}')

    def test_string_arg(self):
        # Ensure both single quotes and double quotes work.
        self.assertEqual(render('{% argument_type name "alice" %}'), 'alice')
        self.assertEqual(render("{% argument_type name 'bob' %}"), 'bob')

        # Ensure a context variable works.
        self.assertEqual(render("{% argument_type name dave %}",
                                {'dave': 'Dave'}),
                         'Dave')

        # Values are cast to unicode.
        class Name(object):
            
            def __init__(self, name):
                self.name = name

            def __unicode__(self):
                return self.name

        self.assertEqual(render('{% argument_type name dave %}',
                                {'dave': Name('dave')}), 'dave')

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type name dave %}')

    def test_datetime_arg(self):
        self.assertEqual(render('{% argument_type datetime dt %}',
                                {'dt': datetime.datetime(2010, 1, 9,
                                                         22, 33, 47)}),
                         '2010-01-09 22:33:47')

        # Fail if variable isn't a datetime.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type datetime dt %}', {'dt': 'NaN'})

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type datetime dt %}')

    def test_date_arg(self):
        self.assertEqual(render('{% argument_type date d %}',
                                {'d': datetime.date(2010, 1, 9)}),
                         '2010-01-09')

        # Fail if variable isn't a datetime.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type date d %}', {'d': 'NaN'})

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type date d %}')

    def test_time_arg(self):
        self.assertEqual(render('{% argument_type time t %}',
                                {'t': datetime.time(22, 33, 47)}),
                         '22:33:47')

        # Fail if variable isn't a datetime.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type time t %}', {'t': 'NaN'})

        # Fail if the variable isn't in the context.
        self.assertRaises(ttag.TagValidationError, render,
                          '{% argument_type time t %}')

    def test_flag_arg(self):
        self.assertEqual(render('{% argument_type %}'), '')
        self.assertEqual(render('{% argument_type flag %}'), 'flag_is_set')

    def test_multi_arg(self):
        self.assertEqual(render('{% dot_combine 1 2 3 4 %}'), '1.2.3.4')
        self.assertEqual(
            render('{% dot_combine_default "a" b "c" default "X" %}',
                   {'b': None}), 'a.X.c')


class KeywordsArgTest(TestCase):
    compact_kwargs = ' "file.html" with foo=x bar=2 %}'
    verbose_kwargs = ' "file.html" with x as foo and 2 as bar %}'
    mixed_kwargs = ' "file.html" with bar=2 x as foo and baz=3 %}'

    def test_not_required(self):
        self.assertEqual(render('{% include_compact "file.html" %}'),
                         'including file.html')
        self.assertEqual(render('{% include_verbose "file.html" %}'),
                         'including file.html')
        self.assertEqual(render('{% include_mixed "file.html" %}'),
                         'including file.html')

    def test_compact(self):
        self.assertEqual(
            render('{% include_compact' + self.compact_kwargs, {'x': 1}),
            'including file.html with bar = 2 and foo = 1'
        )

    def test_compact_invalid(self):
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_compact "file.html" with foo=1 and bar=2 %}'
        )
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_compact' + self.verbose_kwargs
        )
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_compact' + self.mixed_kwargs
        )

    def test_verbose(self):
        self.assertEqual(
            render('{% include_verbose' + self.verbose_kwargs, {'x': 1}),
            'including file.html with bar = 2 and foo = 1'
        )

    def test_verbose_invalid(self):
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_verbose' + self.compact_kwargs
        )
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_verbose' + self.mixed_kwargs
        )

    def test_mixed(self):
        self.assertEqual(
            render('{% include_mixed' + self.mixed_kwargs, {'x': 1}),
            'including file.html with bar = 2 and baz = 3 and foo = 1'
        )

    def test_duplicate_key(self):
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_compact "file.html" with foo=1 foo=2 %}'
        )
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_verbose "file.html" with 1 as foo and 2 as foo %}'
        )
        self.assertRaises(
            template.TemplateSyntaxError, render,
            '{% include_mixed "file.html" with foo=1 2 as foo %}'
        )

    def test_loop(self):
        self.assertEqual(render('|{% for i in "abc" %}{% keywords_echo '
                                'test=forloop.counter %}|{% endfor %}'),
                         '|test: 1|test: 2|test: 3|')



from django import template

from ttag import core, args


class AsTagOptions(core.Options):

    def __init__(self, meta, *args, **kwargs):
        super(AsTagOptions, self).__init__(meta=meta, *args, **kwargs)
        self.as_default = getattr(meta, 'as_default', None)
        if self.as_default:
            self.as_required = False
        else:
            self.as_required = getattr(meta, 'as_required', True)
        self.as_name = getattr(meta, 'as_name', 'as')

    def post_process(self):
        super(AsTagOptions, self).post_process()
        non_keyword_args = [name for name, arg in self.named_args.items()
                            if not arg.keyword]
        if (self.as_name in non_keyword_args and
                self.as_name not in self.parent_args):
            raise template.TemplateSyntaxError(
                "%s can not explicitly define an named argument called %r" %
                (self.name, self.as_name))
        arg = args.BasicArg(required=self.as_required, named=True)
        arg.name = self.as_name
        self.named_args[self.as_name] = arg


class AsTagMetaclass(core.DeclarativeArgsMetaclass):
    options_class = AsTagOptions


class AsTag(core.BaseTag):
    __metaclass__ = AsTagMetaclass

    def render(self, context):
        data = self.resolve(context)
        as_var = data.get(self._meta.as_name, self._meta.as_default)
        value = self.as_value(data, context)
        if as_var:
            context[as_var] = value
            return self.as_output(data, context)
        return value

    def as_value(self, data, context):
        return self.output(data)

    def as_output(self, data, context):
        return ''



import datetime
import ttag

from django import template


register = template.Library()

class SelfReferentialTag(ttag.helpers.TemplateTag):

    def using(self, data):
        return 'ttag/%s/%s.html' % (
            self.__class__.__module__.split('.')[-1].lower(),
            self._meta.name.lower()
        )


class Do(SelfReferentialTag):

    class Meta:
        template_name = 'it'

    def output(self, data):
        return 'done'


class Go(ttag.helpers.TemplateTag):

    def output(self, data):
        return 'home'


class Ask(SelfReferentialTag):
    value = ttag.Arg()

    def output(self, data):
        if "date" in data['value']:
            return datetime.datetime.today()


register.tag(Do)
register.tag(Go)
register.tag(Ask)



from django.template import TemplateSyntaxError
from django.template.loader import render_to_string

from ttag import core, args


class TemplateTagOptions(core.Options):

    def __init__(self, meta, *args, **kwargs):
        super(TemplateTagOptions, self).__init__(meta=meta, *args, **kwargs)
        self.template_name = getattr(meta, 'template_name', 'using')

    def post_process(self):
        super(TemplateTagOptions, self).post_process()
        non_keyword_args = [name for name, arg in self.named_args.items()
                            if not arg.keyword]
        if (self.template_name in non_keyword_args and
                self.template_name not in self.parent_args):
            raise TemplateSyntaxError(
                "%s can not explicitly define a named argument called %r" %
                (self.name, self.template_name))

        arg = args.Arg(required=False, named=True)
        arg.name = self.template_name
        self.named_args[self.template_name] = arg



class TemplateTagMetaclass(core.DeclarativeArgsMetaclass):
    options_class = TemplateTagOptions


class TemplateTag(core.BaseTag):
    __metaclass__ = TemplateTagMetaclass

    def render(self, context):
        data = self.resolve(context)
        template_name = data.get(self._meta.template_name, self.using(data))
        if not template_name:
            raise TemplateSyntaxError(
                "%s wasn't given a template to render with" % self._meta.name)
        extra_context = {
            'data': data,
            'output': self.output(data),
        }
        return render_to_string(template_name, extra_context, context)

    def using(self, data):
        """
        TemplateTag subclasses must implement this method if
        not templates are given as the argument, e.g.::

        class RenderTag(TemplateTag):

            def using(context):
                return 'templatetags/%s.html' % self._meta.name.lower()
        """
        return None



from distutils.core import setup
from ttag import get_version

setup(
    name='django-ttag',
    version=get_version(),
    description="A template tag constructor library for Django.",
    long_description=open('README.rst').read(),
    author='Chris Beaven',
    author_email='chris@lincolnloop.com',
    license='MIT',
    url='http://github.com/lincolnloop/django-ttag',
    packages=[
        'ttag',
        'ttag.tests',
        'ttag.tests.setup',
        'ttag.helpers',
    ],
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Framework :: Django',
    ],
)
